import * as i0 from '@angular/core';
import { EventEmitter, Component, Output, Input, Inject, ViewEncapsulation, NgModule } from '@angular/core';
import * as i1 from '@angular/forms';
import { Validators, FormControl, ReactiveFormsModule } from '@angular/forms';
import * as i1$1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i3$1 from '@angular/material/card';
import { MatCardModule } from '@angular/material/card';
import * as i2 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i5 from '@angular/material/select';
import { MatSelectModule } from '@angular/material/select';
import * as i6 from '@angular/material/core';
import { MatOptionModule, MatNativeDateModule } from '@angular/material/core';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i7 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';
import * as i8 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i7$1 from '@angular/material/slide-toggle';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import * as i12 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import * as i7$2 from '@angular/material/grid-list';
import { MatGridListModule } from '@angular/material/grid-list';
import * as i1$2 from '@angular/router';
import { RouterModule } from '@angular/router';
import * as i4$1 from '@angular/cdk/bidi';
import * as i3$2 from '@angular/material/datepicker';
import { MatDatepickerModule } from '@angular/material/datepicker';
import { MatDividerModule } from '@angular/material/divider';
import { MatRadioModule } from '@angular/material/radio';

const defaultInputConfiguration = {
    componentType: 'input',
    formControlName: null,
    type: { name: 'text', icon: 'article' },
    label: '',
    placeholder: '',
    isInputTypePassword: false,
    themeColor: 'primary',
    isRtl: false,
    autofocus: false,
    readonly: false,
    hint: '',
};

const defaultButtonConfiguration = {
    formControlName: '',
    componentType: 'button',
    type: { name: 'accept', icon: 'check_circle' },
    themeColor: 'primary',
    label: '',
    width: '180',
    isRtl: false,
    tailwindsClassForLabel: '',
    hasToolTip: false,
    tooltipText: '',
    tooltipPosition: 'left',
    tooltipHideDelay: 0,
    hasIcon: false,
    icon: '',
    localNavigationUrl: '',
    externalLink: '',
};

const defaultDatepickerConfiguration = {
    componentType: 'datepicker',
    formControlName: '',
    appearance: 'outline',
    label: '',
    themeColor: 'primary',
    popupColor: 'primary',
    isRtl: false,
    hint: '',
    disableMode: 'input',
    datePickerIcon: 'calendar_today',
    locale: 'en-US',
};

const defaultComponentsList = [
    { componentType: 'input', defaultComponent: defaultInputConfiguration },
    { componentType: 'button', defaultComponent: defaultButtonConfiguration },
    { componentType: 'date', defaultComponent: defaultDatepickerConfiguration },
];

class AgButtonConfigurationComponent {
    constructor(fb) {
        this.fb = fb;
        this.themeColors = ['primary', 'accent', 'warn'];
        this.componentConfiguration = new EventEmitter();
        this.buttonTypes = [
            { name: 'accept', icon: 'check_circle' },
            { name: 'reject', icon: 'cancel' },
            { name: 'upload', icon: 'upload' },
            { name: 'download', icon: 'download' },
            { name: 'local Route', icon: 'alt_route' },
            { name: 'externalLink', icon: 'link' },
        ];
        this.form = this.fb.group({
            componentType: [''],
            formControlName: [null, [Validators.required, Validators.pattern(/^[a-zA-Z]*$/)]],
            type: ['', Validators.required],
            width: ['', Validators.required],
            themeColor: ['primary', Validators.required],
            label: ['', Validators.required],
            tooltipText: [''],
        });
    }
    ngOnInit() {
        this.form.get('type').valueChanges.subscribe((value) => {
            value.name === 'download' || value.name === 'externalLink'
                ? this.form.addControl('downloadOrExternalNavigateLink', new FormControl('', Validators.required))
                : !this.form.get('downloadOrExternalNavigateLink') && this.form.removeControl('downloadOrExternalNavigateLink');
        });
        this.setDataForEditMode();
    }
    submitComponentConfigurationForm() {
        const data = this.form.value;
        this.componentConfiguration.emit(data);
    }
    setDataForEditMode() {
        var _a, _b, _c, _d, _e, _f;
        (_a = this.form.get('componentType')) === null || _a === void 0 ? void 0 : _a.setValue(this.buttonConfiguration.componentType);
        (_b = this.form.get('formControlName')) === null || _b === void 0 ? void 0 : _b.setValue(this.buttonConfiguration.formControlName);
        (_c = this.form.get('width')) === null || _c === void 0 ? void 0 : _c.setValue(this.buttonConfiguration.width);
        (_d = this.form.get('label')) === null || _d === void 0 ? void 0 : _d.setValue(this.buttonConfiguration.label);
        (_e = this.form.get('themeColor')) === null || _e === void 0 ? void 0 : _e.setValue(this.buttonConfiguration.themeColor);
        (_f = this.form.get('tooltipText')) === null || _f === void 0 ? void 0 : _f.setValue(this.buttonConfiguration.tooltipText);
        this.buttonTypes.map((buttonType) => { var _a; return buttonType.name === this.buttonConfiguration.type.name && ((_a = this.form.get('type')) === null || _a === void 0 ? void 0 : _a.setValue(buttonType)); });
    }
}
AgButtonConfigurationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonConfigurationComponent, deps: [{ token: i1.FormBuilder }], target: i0.ɵɵFactoryTarget.Component });
AgButtonConfigurationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgButtonConfigurationComponent, selector: "ag-button-configuration", inputs: { buttonConfiguration: "buttonConfiguration" }, outputs: { componentConfiguration: "componentConfiguration" }, ngImport: i0, template: "<form (submit)=\"submitComponentConfigurationForm()\" [formGroup]=\"form\" class=\"ag-flex ag-flex-col ag-h-full\">\n    <div class=\"ag-h-5-6 ag-overflow-y-auto ag-flex ag-flex-col\">\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Form Control Name</mat-label>\n            <input matInput type=\"text\" formControlName=\"formControlName\" pattern=\"[a-zA-Z ]*\" />\n            <button *ngIf=\"form.get('formControlName')!.value\" matSuffix mat-icon-button (click)=\"form.get('formControlName')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n            <mat-error *ngIf=\"form.get('formControlName')!.hasError('pattern')\"> You should only use English letters for this field </mat-error>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Label</mat-label>\n            <input matInput type=\"text\" formControlName=\"label\" />\n            <button *ngIf=\"form.get('label')!.value\" matSuffix mat-icon-button (click)=\"form.get('label')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Tooltip</mat-label>\n            <input matInput type=\"text\" formControlName=\"tooltipText\" />\n            <button *ngIf=\"form.get('tooltipText')!.value\" matSuffix mat-icon-button (click)=\"form.get('tooltipText')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Button Type</mat-label>\n            <mat-select formControlName=\"type\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">{{ form.get('type')!.value.icon }}</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('type')!.value.name | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let buttonType of buttonTypes\" [value]=\"buttonType\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">{{ buttonType.icon }}</mat-icon>\n                    <span>{{ buttonType.name | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <mat-form-field\n            appearance=\"outline\"\n            class=\"ag-mx-3\"\n            *ngIf=\"form.get('type')!.value.name === 'externalLink' || form.get('type')!.value.name === 'download'\"\n        >\n            <mat-label>Link</mat-label>\n            <input matInput type=\"text\" formControlName=\"downloadOrExternalNavigateLink\" />\n            <button *ngIf=\"form.get('tooltipText')!.value\" matSuffix mat-icon-button (click)=\"form.get('downloadOrExternalNavigateLink')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Button theme</mat-label>\n            <mat-select formControlName=\"themeColor\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"form.get('themeColor')!.value\">circle</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('themeColor')!.value | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let themeColor of themeColors\" [value]=\"themeColor\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"themeColor\">circle</mat-icon>\n                    <span>{{ themeColor | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n    </div>\n\n    <button class=\"ag-w-3-5 ag-mx-auto ag-my-auto\" mat-flat-button color=\"primary\" type=\"submit\" [disabled]=\"form.invalid\">\n        <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-mx-2\">save</mat-icon>\n        <span>Save Component Settings</span>\n    </button>\n</form>\n", styles: [""], components: [{ type: i2.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i5.MatSelect, selector: "mat-select", inputs: ["disabled", "disableRipple", "tabIndex"], exportAs: ["matSelect"] }, { type: i6.MatOption, selector: "mat-option", exportAs: ["matOption"] }], directives: [{ type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i2.MatLabel, selector: "mat-label" }, { type: i7.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["id", "disabled", "required", "type", "value", "readonly", "placeholder", "errorStateMatcher", "aria-describedby"], exportAs: ["matInput"] }, { type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i1.FormControlName, selector: "[formControlName]", inputs: ["disabled", "formControlName", "ngModel"], outputs: ["ngModelChange"] }, { type: i1.PatternValidator, selector: "[pattern][formControlName],[pattern][formControl],[pattern][ngModel]", inputs: ["pattern"] }, { type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.MatSuffix, selector: "[matSuffix]" }, { type: i2.MatError, selector: "mat-error", inputs: ["id"] }, { type: i5.MatSelectTrigger, selector: "mat-select-trigger" }, { type: i8.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], pipes: { "titlecase": i8.TitleCasePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonConfigurationComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'ag-button-configuration',
                    templateUrl: './ag-button-configuration.component.html',
                    styleUrls: ['./ag-button-configuration.component.scss'],
                }]
        }], ctorParameters: function () { return [{ type: i1.FormBuilder }]; }, propDecorators: { componentConfiguration: [{
                type: Output
            }], buttonConfiguration: [{
                type: Input
            }] } });

class AgInputConfigurationComponent {
    constructor(fb) {
        this.fb = fb;
        this.themeColors = ['primary', 'accent', 'warn'];
        this.componentConfiguration = new EventEmitter();
        this.inputTypes = [
            { name: 'text', icon: 'article' },
            { name: 'email', icon: 'email' },
            { name: 'tel', icon: 'phone' },
            { name: 'url', icon: 'link' },
            { name: 'numeric', icon: 'pin' },
        ];
        this.form = this.fb.group({
            componentType: ['input'],
            formControlName: [null, [Validators.required, Validators.pattern(/^[a-zA-Z]*$/)]],
            type: [null, Validators.required],
            label: ['', Validators.required],
            placeholder: [''],
            isInputTypePassword: [false, Validators.required],
            themeColor: ['primary', Validators.required],
            isRtl: [false, Validators.required],
            hint: [''],
        });
    }
    ngOnInit() {
        this.setFormValue();
    }
    submitComponentConfigurationForm() {
        const data = {
            componentType: this.form.get('componentType').value,
            formControlName: this.form.get('formControlName').value,
            type: this.form.get('type').value,
            label: this.form.get('label').value,
            placeholder: this.form.get('placeholder').value,
            isInputTypePassword: this.form.get('isInputTypePassword').value,
            themeColor: this.form.get('themeColor').value,
            isRtl: this.form.get('isRtl').value,
            hint: this.form.get('hint').value,
        };
        this.componentConfiguration.emit(data);
    }
    setFormValue() {
        var _a, _b, _c, _d, _e, _f, _g, _h;
        if (!!this.inputConfiguration.formControlName) {
            (_a = this.form.get('formControlName')) === null || _a === void 0 ? void 0 : _a.setValue(this.inputConfiguration.formControlName);
        }
        (_b = this.form.get('componentType')) === null || _b === void 0 ? void 0 : _b.setValue(this.inputConfiguration.componentType);
        (_c = this.form.get('label')) === null || _c === void 0 ? void 0 : _c.setValue(this.inputConfiguration.label);
        (_d = this.form.get('placeholder')) === null || _d === void 0 ? void 0 : _d.setValue(this.inputConfiguration.placeholder);
        (_e = this.form.get('isInputTypePassword')) === null || _e === void 0 ? void 0 : _e.setValue(this.inputConfiguration.isInputTypePassword);
        (_f = this.form.get('themeColor')) === null || _f === void 0 ? void 0 : _f.setValue(this.inputConfiguration.themeColor);
        (_g = this.form.get('isRtl')) === null || _g === void 0 ? void 0 : _g.setValue(this.inputConfiguration.isRtl);
        (_h = this.form.get('hint')) === null || _h === void 0 ? void 0 : _h.setValue(this.inputConfiguration.hint);
        this.inputTypes.map((inputType) => { var _a; return inputType.name === this.inputConfiguration.type.name && ((_a = this.form.get('type')) === null || _a === void 0 ? void 0 : _a.setValue(inputType)); });
    }
}
AgInputConfigurationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputConfigurationComponent, deps: [{ token: i1.FormBuilder }], target: i0.ɵɵFactoryTarget.Component });
AgInputConfigurationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgInputConfigurationComponent, selector: "ag-input-configuration", inputs: { inputConfiguration: "inputConfiguration" }, outputs: { componentConfiguration: "componentConfiguration" }, ngImport: i0, template: "<form (submit)=\"submitComponentConfigurationForm()\" [formGroup]=\"form\" class=\"ag-flex ag-flex-col ag-h-full\">\n    <div class=\"ag-h-5-6 ag-overflow-y-auto ag-flex ag-flex-col\">\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Form Control Name</mat-label>\n            <input matInput type=\"text\" formControlName=\"formControlName\" pattern=\"[a-zA-Z ]*\" />\n            <button *ngIf=\"form.get('formControlName')!.value\" matSuffix mat-icon-button (click)=\"form.get('formControlName')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n            <mat-error *ngIf=\"form.get('formControlName')!.hasError('pattern')\"> You should only use English letters for this field </mat-error>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Input Type</mat-label>\n            <mat-select formControlName=\"type\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">{{ form.get('type')!.value.icon }}</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('type')!.value.name | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let inputType of inputTypes\" [value]=\"inputType\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">{{ inputType.icon }}</mat-icon>\n                    <span>{{ inputType.name | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Label</mat-label>\n            <input matInput type=\"text\" formControlName=\"label\" />\n            <button *ngIf=\"form.get('label')!.value\" matSuffix mat-icon-button (click)=\"form.get('label')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Placeholder</mat-label>\n            <input matInput type=\"text\" formControlName=\"placeholder\" />\n            <button *ngIf=\"form.get('placeholder')!.value\" matSuffix mat-icon-button (click)=\"form.get('placeholder')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Hint</mat-label>\n            <input matInput type=\"text\" formControlName=\"hint\" />\n            <button *ngIf=\"form.get('hint')!.value\" matSuffix mat-icon-button (click)=\"form.get('hint')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Input theme</mat-label>\n            <mat-select formControlName=\"themeColor\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"form.get('themeColor')!.value\">circle</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('themeColor')!.value | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let themeColor of themeColors\" [value]=\"themeColor\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"themeColor\">circle</mat-icon>\n                    <span>{{ themeColor | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <div class=\"ag-mx-3 ag-mb-3-5\">\n            <mat-slide-toggle class=\"ag-my-2\" formControlName=\"isInputTypePassword\" color=\"primary\">\n                Is your input component's type password?\n            </mat-slide-toggle>\n            <mat-slide-toggle class=\"ag-my-2\" formControlName=\"isRtl\" color=\"primary\"> Is your input component's alignment RTL? </mat-slide-toggle>\n        </div>\n    </div>\n\n    <button class=\"ag-w-3-5 ag-mx-auto ag-my-auto\" mat-flat-button color=\"primary\" type=\"submit\" [disabled]=\"form.invalid\">\n        <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-mx-2\">save</mat-icon>\n        <span>Save Component Settings</span>\n    </button>\n</form>\n", styles: [""], components: [{ type: i2.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i5.MatSelect, selector: "mat-select", inputs: ["disabled", "disableRipple", "tabIndex"], exportAs: ["matSelect"] }, { type: i6.MatOption, selector: "mat-option", exportAs: ["matOption"] }, { type: i7$1.MatSlideToggle, selector: "mat-slide-toggle", inputs: ["disabled", "disableRipple", "color", "tabIndex", "name", "id", "labelPosition", "aria-label", "aria-labelledby", "required", "checked", "aria-describedby"], outputs: ["change", "toggleChange"], exportAs: ["matSlideToggle"] }], directives: [{ type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i2.MatLabel, selector: "mat-label" }, { type: i7.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["id", "disabled", "required", "type", "value", "readonly", "placeholder", "errorStateMatcher", "aria-describedby"], exportAs: ["matInput"] }, { type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i1.FormControlName, selector: "[formControlName]", inputs: ["disabled", "formControlName", "ngModel"], outputs: ["ngModelChange"] }, { type: i1.PatternValidator, selector: "[pattern][formControlName],[pattern][formControl],[pattern][ngModel]", inputs: ["pattern"] }, { type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.MatSuffix, selector: "[matSuffix]" }, { type: i2.MatError, selector: "mat-error", inputs: ["id"] }, { type: i5.MatSelectTrigger, selector: "mat-select-trigger" }, { type: i8.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], pipes: { "titlecase": i8.TitleCasePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputConfigurationComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'ag-input-configuration',
                    templateUrl: './ag-input-configuration.component.html',
                    styleUrls: ['./ag-input-configuration.component.scss'],
                }]
        }], ctorParameters: function () { return [{ type: i1.FormBuilder }]; }, propDecorators: { componentConfiguration: [{
                type: Output
            }], inputConfiguration: [{
                type: Input
            }] } });

class AgDatePickerConfigurationComponent {
    constructor(fb) {
        this.fb = fb;
        this.themeColors = ['primary', 'accent', 'warn'];
        this.appearances = ['outline', 'legacy', 'standard', 'fill'];
        this.disableModes = [
            { name: 'popup', icon: 'open_in_new_off' },
            { name: 'input', icon: 'power_input' },
            { name: 'none', icon: 'check_box_outline_blank' },
            { name: 'whole', icon: 'event' },
        ];
        this.datePickerIcons = ['event', 'calendar_today', 'today', 'edit_calendar', 'calendar_view_month'];
        this.datePickerLocales = [
            { localeCode: 'fa-IR', localeName: 'Iranian Calendar' },
            { localeCode: 'en-US', localeName: 'Gregorian Calendar' },
        ];
        this.componentConfiguration = new EventEmitter();
        this.form = this.fb.group({
            formControlName: [null, [Validators.required, Validators.pattern(/^[a-zA-Z]*$/)]],
            label: ['', Validators.required],
            componentType: ['datepicker'],
            datePickerIcon: ['', Validators.required],
            themeColor: ['primary', Validators.required],
            popupColor: ['', Validators.required],
            locale: [Validators.required],
            disableMode: ['input', Validators.required],
            hint: [''],
            appearance: ['outline', Validators.required],
        });
    }
    ngOnInit() {
        this.setDataForEditMode();
    }
    submitComponentConfigurationForm() {
        const data = this.form.value;
        this.componentConfiguration.emit(data);
        console.log(data);
        console.log(this.form.value);
    }
    setDataForEditMode() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        (_a = this.form.get('componentType')) === null || _a === void 0 ? void 0 : _a.setValue(this.datepickerConfiguration.componentType);
        (_b = this.form.get('formControlName')) === null || _b === void 0 ? void 0 : _b.setValue(this.datepickerConfiguration.formControlName);
        (_c = this.form.get('appearance')) === null || _c === void 0 ? void 0 : _c.setValue(this.datepickerConfiguration.appearance);
        (_d = this.form.get('label')) === null || _d === void 0 ? void 0 : _d.setValue(this.datepickerConfiguration.label);
        (_e = this.form.get('themeColor')) === null || _e === void 0 ? void 0 : _e.setValue(this.datepickerConfiguration.themeColor);
        (_f = this.form.get('locale')) === null || _f === void 0 ? void 0 : _f.setValue(this.datepickerConfiguration.locale);
        (_g = this.form.get('disableMode')) === null || _g === void 0 ? void 0 : _g.setValue(this.datepickerConfiguration.disableMode);
        (_h = this.form.get('popupColor')) === null || _h === void 0 ? void 0 : _h.setValue(this.datepickerConfiguration.popupColor);
        (_j = this.form.get('datePickerIcon')) === null || _j === void 0 ? void 0 : _j.setValue(this.datepickerConfiguration.datePickerIcon);
    }
    setLocaleName(localeCode) {
        console.log(localeCode);
        return this.datePickerLocales.find((item) => item.localeCode === localeCode).localeName;
    }
    findDisableModeIcon(mode) {
        return this.disableModes.find((item) => item.name === mode).icon;
    }
}
AgDatePickerConfigurationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerConfigurationComponent, deps: [{ token: i1.FormBuilder }], target: i0.ɵɵFactoryTarget.Component });
AgDatePickerConfigurationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgDatePickerConfigurationComponent, selector: "ag-date-picker-configuration", inputs: { datepickerConfiguration: "datepickerConfiguration" }, outputs: { componentConfiguration: "componentConfiguration" }, ngImport: i0, template: "<form (submit)=\"submitComponentConfigurationForm()\" [formGroup]=\"form\" class=\"ag-flex ag-flex-col ag-h-full\">\n    <div class=\"ag-h-5-6 ag-overflow-y-auto ag-flex ag-flex-col\">\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Form Control Name</mat-label>\n            <input matInput type=\"text\" formControlName=\"formControlName\" pattern=\"[a-zA-Z ]*\" />\n            <button *ngIf=\"form.get('formControlName')!.value\" matSuffix mat-icon-button (click)=\"form.get('formControlName')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n            <mat-error *ngIf=\"form.get('formControlName')!.hasError('pattern')\"> You should only use English letters for this field </mat-error>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Label</mat-label>\n            <input matInput type=\"text\" formControlName=\"label\" />\n            <button *ngIf=\"form.get('label')!.value\" matSuffix mat-icon-button (click)=\"form.get('label')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Hint</mat-label>\n            <input matInput type=\"text\" formControlName=\"hint\" />\n            <button *ngIf=\"form.get('hint')!.value\" matSuffix mat-icon-button (click)=\"form.get('hint')?.setValue('')\">\n                <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n            </button>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Appearance</mat-label>\n            <mat-select formControlName=\"appearance\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"accent\">format_color_fill</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('appearance')!.value | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let appearance of appearances\" [value]=\"appearance\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"accent\">format_color_fill</mat-icon>\n                    <span>{{ appearance | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Disable Mode</mat-label>\n            <mat-select formControlName=\"disableMode\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"warn\">{{ findDisableModeIcon(form.get('disableMode')!.value) }}</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('disableMode')!.value | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let disableMode of disableModes\" [value]=\"disableMode.name\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"warn\">{{ disableMode.icon }}</mat-icon>\n                    <span>{{ disableMode.name | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Datepicker theme</mat-label>\n            <mat-select formControlName=\"themeColor\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"form.get('themeColor')!.value\">circle</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('themeColor')!.value | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let themeColor of themeColors\" [value]=\"themeColor\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"themeColor\">circle</mat-icon>\n                    <span>{{ themeColor | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Popup theme</mat-label>\n            <mat-select formControlName=\"popupColor\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"form.get('popupColor')!.value\">circle</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('popupColor')!.value | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let themeColor of themeColors\" [value]=\"themeColor\">\n                    <mat-icon fontSet=\"material-icons-outlined\" [color]=\"themeColor\">circle</mat-icon>\n                    <span>{{ themeColor | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Datepicker icon</mat-label>\n            <mat-select formControlName=\"datePickerIcon\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">{{ form.get('datePickerIcon')!.value }}</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ form.get('datePickerIcon')!.value | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let datePickerIcon of datePickerIcons\" [value]=\"datePickerIcon\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">{{ datePickerIcon }}</mat-icon>\n                    <span>{{ datePickerIcon | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n\n        <mat-form-field appearance=\"outline\" class=\"ag-mx-3\">\n            <mat-label>Datepicker Locale</mat-label>\n            <mat-select formControlName=\"locale\">\n                <mat-select-trigger class=\"ag-flex\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">calendar_today</mat-icon>\n                    <span style=\"line-height: 24px\" class=\"ag-mx-4\">{{ setLocaleName(form.get('locale')!.value) | titlecase }}</span>\n                </mat-select-trigger>\n                <mat-option *ngFor=\"let datePickerLocale of datePickerLocales\" [value]=\"datePickerLocale.localeCode\">\n                    <mat-icon fontSet=\"material-icons-outlined\" color=\"primary\">calendar_today</mat-icon>\n                    <span>{{ datePickerLocale.localeName | titlecase }}</span>\n                </mat-option>\n            </mat-select>\n        </mat-form-field>\n    </div>\n\n    <button class=\"ag-w-3-5 ag-mx-auto ag-my-auto\" mat-flat-button color=\"primary\" type=\"submit\" [disabled]=\"form.invalid\">\n        <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-mx-2\">save</mat-icon>\n        <span>Save Component Settings</span>\n    </button>\n</form>\n", styles: [""], components: [{ type: i2.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i5.MatSelect, selector: "mat-select", inputs: ["disabled", "disableRipple", "tabIndex"], exportAs: ["matSelect"] }, { type: i6.MatOption, selector: "mat-option", exportAs: ["matOption"] }], directives: [{ type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i2.MatLabel, selector: "mat-label" }, { type: i7.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["id", "disabled", "required", "type", "value", "readonly", "placeholder", "errorStateMatcher", "aria-describedby"], exportAs: ["matInput"] }, { type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i1.FormControlName, selector: "[formControlName]", inputs: ["disabled", "formControlName", "ngModel"], outputs: ["ngModelChange"] }, { type: i1.PatternValidator, selector: "[pattern][formControlName],[pattern][formControl],[pattern][ngModel]", inputs: ["pattern"] }, { type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.MatSuffix, selector: "[matSuffix]" }, { type: i2.MatError, selector: "mat-error", inputs: ["id"] }, { type: i5.MatSelectTrigger, selector: "mat-select-trigger" }, { type: i8.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }], pipes: { "titlecase": i8.TitleCasePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerConfigurationComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'ag-date-picker-configuration',
                    templateUrl: './ag-date-picker-configuration.component.html',
                    styleUrls: ['./ag-date-picker-configuration.component.scss'],
                }]
        }], ctorParameters: function () { return [{ type: i1.FormBuilder }]; }, propDecorators: { componentConfiguration: [{
                type: Output
            }], datepickerConfiguration: [{
                type: Input
            }] } });

class AgSettingModalComponent {
    constructor(matDialog, data) {
        this.matDialog = matDialog;
        this.data = data;
        this.columns = [];
        this.sectionInfo = {
            sectionIndex: this.data.sectionIndex,
            sectionColumns: [],
        };
        if (this.data.sectionInfo.columnsCount > 0)
            this.setDataForEditMode();
    }
    addColumn(componentType) {
        this.columns.push({
            columnId: 1,
            columnComponentType: 'input',
            columnSetting: this.addDefaultComponentConfigurationBasedOnSelectedComponent(componentType),
        });
    }
    addDefaultComponentConfigurationBasedOnSelectedComponent(componentType) {
        const component = defaultComponentsList.find((item) => item.componentType === componentType);
        return component.defaultComponent;
    }
    removeColumn(column) {
        const columnIndex = this.columns.indexOf(column);
        this.columns.splice(columnIndex, 1);
        this.sectionInfo.sectionColumns.splice(columnIndex, 1);
    }
    checkColumnsCountForLessThanThree() {
        return this.columns.length < 3;
    }
    discardSectionSettings() {
        this.matDialog.close(false);
    }
    saveSectionSettings() {
        this.matDialog.close(this.sectionInfo);
    }
    getComponentConfigurationEvent(event, componentType, columnIndex) {
        this.sectionInfo.sectionColumns[columnIndex] = { index: columnIndex, componentType: componentType, componentInfo: event };
    }
    setDataForEditMode() {
        this.columns = [];
        this.data.sectionInfo.columnInfo.map((item) => {
            this.columns.push({ columnId: item.index, columnComponentType: item.componentType, columnSetting: item.componentInfo });
            this.sectionInfo.sectionColumns.push({ index: item.index, componentInfo: item.componentInfo, componentType: item.componentType });
        });
    }
    returnInputFormConfiguration(sectionColumn) {
        return this.columns.length > 0 ? sectionColumn.columnSetting : defaultInputConfiguration;
    }
    returnButtonFormConfiguration(sectionColumn) {
        return this.columns.length > 0 ? sectionColumn.columnSetting : defaultButtonConfiguration;
    }
    returnDatepickerFormConfiguration(sectionColumn) {
        return this.columns.length > 0 ? sectionColumn.columnSetting : defaultDatepickerConfiguration;
    }
    onComponentTypeValueChange(column, selectedColumnComponentType) {
        const columnIndex = this.columns.indexOf(column);
        this.columns[columnIndex] = {
            columnSetting: this.addDefaultComponentConfigurationBasedOnSelectedComponent(selectedColumnComponentType),
            columnId: this.columns[columnIndex].columnId,
            columnComponentType: selectedColumnComponentType,
        };
    }
}
AgSettingModalComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgSettingModalComponent, deps: [{ token: i1$1.MatDialogRef }, { token: MAT_DIALOG_DATA }], target: i0.ɵɵFactoryTarget.Component });
AgSettingModalComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgSettingModalComponent, selector: "ag-setting-modal", ngImport: i0, template: "<div class=\"ag-flex ag-flex-col ag-justify-between ag-h-full\">\n    <div class=\"ag-flex ag-justify-center ag-items-center ag-grid ag-grid-cols-3\">\n        <mat-card *ngFor=\"let column of columns; let index = index\" class=\"ag-bg-gray-100 ag-mx-2 ag-flex ag-flex-col ag-h-full\">\n            <div class=\"ag-max-w-full ag-text-center ag-w-full ag-mx-0 ag-px-3-5\">\n                <mat-card-title class=\"ag-text-base ag-w-full ag-flex ag-justify-center ag-items-baseline\">\n                    <mat-form-field appearance=\"outline\" class=\"ag-w-full ag-p-0 ag-m-0\">\n                        <mat-label>Select your component type</mat-label>\n                        <mat-select [value]=\"column.columnComponentType ?? 'input'\" #matSelect (valueChange)=\"onComponentTypeValueChange(column, $event)\">\n                            <mat-option value=\"input\">Input Component</mat-option>\n                            <mat-option value=\"button\">Button Component</mat-option>\n                            <mat-option value=\"date\">Datepicker Component</mat-option>\n                        </mat-select>\n                    </mat-form-field>\n\n                    <button class=\"ag-ml-4\" mat-icon-button color=\"warn\" matTooltip=\"Remove Column\" matTooltipPosition=\"below\" (click)=\"removeColumn(column)\">\n                        <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-4xl\" inline>highlight_off</mat-icon>\n                    </button>\n                </mat-card-title>\n\n                <mat-card-subtitle>\n                    <p class=\"ag-text-center ag-text-lg ag-font-black\">{{ matSelect.value === 'input' ? 'Input ' : 'Button ' }}Component Configuration</p>\n                </mat-card-subtitle>\n            </div>\n\n            <mat-card-content class=\"ag-overflow-y-auto ag-h-5-6\">\n                <!--  Button Component  -->\n\n                <ag-button-configuration\n                    *ngIf=\"matSelect.value === 'button'\"\n                    [buttonConfiguration]=\"returnButtonFormConfiguration(column)\"\n                    (componentConfiguration)=\"getComponentConfigurationEvent($event, 'button', index)\"\n                ></ag-button-configuration>\n\n                <!--  Input Component  -->\n                <ag-input-configuration\n                    *ngIf=\"matSelect.value === 'input'\"\n                    [inputConfiguration]=\"returnInputFormConfiguration(column)\"\n                    (componentConfiguration)=\"getComponentConfigurationEvent($event, 'input', index)\"\n                ></ag-input-configuration>\n\n                <ag-date-picker-configuration\n                    *ngIf=\"matSelect.value === 'date'\"\n                    [datepickerConfiguration]=\"returnDatepickerFormConfiguration(column)\"\n                    (componentConfiguration)=\"getComponentConfigurationEvent($event, 'date', index)\"\n                ></ag-date-picker-configuration>\n            </mat-card-content>\n        </mat-card>\n\n        <button mat-button [disableRipple]=\"true\" (click)=\"addColumn('input')\" matTooltip=\"Add new Column\" matTooltipPosition=\"below\" class=\"ag-p-0\">\n            <mat-card\n                *ngIf=\"checkColumnsCountForLessThanThree()\"\n                class=\"ag-flex ag-flex-col ag-justify-center ag-items-center ag-bg-gray-100 ag-mx-5 ag-h-5-6 empty-state-section ag-m-0\"\n            >\n                <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-blue-600 ag-text-7xl ag-flex ag-justify-center ag-items-center\"\n                    >add_circle\n                </mat-icon>\n            </mat-card>\n        </button>\n    </div>\n\n    <div class=\"ag-flex ag-justify-evenly ag-items-end\">\n        <button mat-flat-button color=\"warn\" matTooltip=\"Close Section Settings\" matTooltipPosition=\"below\" (click)=\"discardSectionSettings()\">\n            <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-3xl\" inline>close</mat-icon>\n            <span>Close Section Settings</span>\n        </button>\n\n        <button mat-flat-button color=\"primary\" matTooltip=\"Close Section Settings\" matTooltipPosition=\"below\" (click)=\"saveSectionSettings()\">\n            <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-3xl\" inline>save</mat-icon>\n            <span>Save Section Settings</span>\n        </button>\n    </div>\n</div>\n", styles: ["mat-card{min-height:680px;max-height:680px}.empty-state-section{border:3px dashed #3f51b5;opacity:.8;background:#e1edfc repeating-linear-gradient(45deg,#e7f4ff,#e7f4ff 5px,#e1edfc 5px,#e1edfc 25px)}\n"], components: [{ type: i3$1.MatCard, selector: "mat-card", exportAs: ["matCard"] }, { type: i2.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i5.MatSelect, selector: "mat-select", inputs: ["disabled", "disableRipple", "tabIndex"], exportAs: ["matSelect"] }, { type: i6.MatOption, selector: "mat-option", exportAs: ["matOption"] }, { type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: AgButtonConfigurationComponent, selector: "ag-button-configuration", inputs: ["buttonConfiguration"], outputs: ["componentConfiguration"] }, { type: AgInputConfigurationComponent, selector: "ag-input-configuration", inputs: ["inputConfiguration"], outputs: ["componentConfiguration"] }, { type: AgDatePickerConfigurationComponent, selector: "ag-date-picker-configuration", inputs: ["datepickerConfiguration"], outputs: ["componentConfiguration"] }], directives: [{ type: i8.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i3$1.MatCardTitle, selector: "mat-card-title, [mat-card-title], [matCardTitle]" }, { type: i2.MatLabel, selector: "mat-label" }, { type: i12.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { type: i3$1.MatCardSubtitle, selector: "mat-card-subtitle, [mat-card-subtitle], [matCardSubtitle]" }, { type: i3$1.MatCardContent, selector: "mat-card-content, [mat-card-content], [matCardContent]" }, { type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgSettingModalComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'ag-setting-modal',
                    templateUrl: './ag-setting-modal.component.html',
                    styleUrls: ['./ag-setting-modal.component.scss'],
                }]
        }], ctorParameters: function () { return [{ type: i1$1.MatDialogRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }]; } });

class AgButtonComponent {
    constructor(router) {
        this.router = router;
        this.disableButton = false;
    }
    handleClick() {
        if (!this.buttonConfiguration.localNavigationUrl && this.buttonConfiguration.externalLink) {
            window.location.href = this.buttonConfiguration.externalLink;
        }
        else if (this.buttonConfiguration.localNavigationUrl && !this.buttonConfiguration.externalLink) {
            this.router.navigate([`${this.buttonConfiguration.localNavigationUrl}`]).finally();
        }
    }
}
AgButtonComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonComponent, deps: [{ token: i1$2.Router }], target: i0.ɵɵFactoryTarget.Component });
AgButtonComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgButtonComponent, selector: "ag-button", inputs: { disableButton: "disableButton", buttonConfiguration: "buttonConfiguration" }, ngImport: i0, template: "<a (click)=\"handleClick()\" [dir]=\"buttonConfiguration.isRtl ? 'rtl' : 'ltr'\">\n    <button\n        mat-flat-button\n        [style.width.px]=\"buttonConfiguration.width\"\n        [routerLink]=\"buttonConfiguration.localNavigationUrl\"\n        [matTooltip]=\"buttonConfiguration.tooltipText ?? ''\"\n        [matTooltipDisabled]=\"!buttonConfiguration.hasToolTip\"\n        [matTooltipPosition]=\"buttonConfiguration.tooltipPosition ?? 'below'\"\n        [matTooltipHideDelay]=\"buttonConfiguration.tooltipHideDelay ?? 0\"\n        [color]=\"buttonConfiguration.themeColor\"\n        [disabled]=\"disableButton\"\n    >\n        <span [className]=\"buttonConfiguration.tailwindsClassForLabel\">{{ buttonConfiguration.label }}</span>\n        <mat-icon fontSet=\"material-icons-outlined\" *ngIf=\"buttonConfiguration.hasIcon\">{{ buttonConfiguration.icon }}</mat-icon>\n    </button>\n</a>\n", styles: [""], components: [{ type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], directives: [{ type: i4$1.Dir, selector: "[dir]", inputs: ["dir"], outputs: ["dirChange"], exportAs: ["dir"] }, { type: i1$2.RouterLink, selector: ":not(a):not(area)[routerLink]", inputs: ["routerLink", "queryParams", "fragment", "queryParamsHandling", "preserveFragment", "skipLocationChange", "replaceUrl", "state", "relativeTo"] }, { type: i12.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'ag-button',
                    templateUrl: './ag-button.component.html',
                    styleUrls: ['./ag-button.component.scss'],
                }]
        }], ctorParameters: function () { return [{ type: i1$2.Router }]; }, propDecorators: { disableButton: [{
                type: Input
            }], buttonConfiguration: [{
                type: Input
            }] } });

class AgInputComponent {
    constructor() {
        this.hideInputTextForPasswordInputs = false;
        this.readonlyForDemo = false;
        this.inputFormConfiguration = {
            componentType: 'input',
            formControlName: '',
            type: { name: 'text', icon: 'article' },
            placeholder: 'placeholder',
            label: 'test',
            isInputTypePassword: true,
            themeColor: 'primary',
            isRtl: false,
            autofocus: false,
            readonly: false,
            errorMessages: [{ errorName: 'email', errorMessage: 'hello' }],
            hint: 'hint',
        };
    }
    ngOnChanges() {
        if (this.inputFormConfiguration.isInputTypePassword)
            this.hideInputTextForPasswordInputs = true;
    }
}
AgInputComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
AgInputComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgInputComponent, selector: "ag-input", inputs: { readonlyForDemo: "readonlyForDemo", inputFormConfiguration: "inputFormConfiguration" }, usesOnChanges: true, ngImport: i0, template: "<mat-form-field appearance=\"outline\" [color]=\"inputFormConfiguration.themeColor\">\n    <mat-label>{{ inputFormConfiguration.label }}</mat-label>\n    <input\n        matInput\n        [attr.placeholder]=\"inputFormConfiguration.placeholder\"\n        [type]=\"hideInputTextForPasswordInputs ? 'password' : inputFormConfiguration.type.name\"\n        [class.text-ltr]=\"inputFormConfiguration.isRtl\"\n        [attr.type]=\"inputFormConfiguration.type.name === 'numeric' ? 'number' : inputFormConfiguration.type.name\"\n        [attr.inputmode]=\"inputFormConfiguration.type\"\n        [readonly]=\"inputFormConfiguration.readonly || readonlyForDemo\"\n        [autofocus]=\"inputFormConfiguration.autofocus\"\n    />\n    <button\n        *ngIf=\"inputFormConfiguration.isInputTypePassword\"\n        type=\"button\"\n        mat-icon-button\n        matSuffix\n        (click)=\"hideInputTextForPasswordInputs = !hideInputTextForPasswordInputs\"\n    >\n        <mat-icon fontSet=\"material-icons-outlined\">{{ hideInputTextForPasswordInputs ? 'visibility_off' : 'remove_red_eye' }}</mat-icon>\n    </button>\n    <mat-hint *ngIf=\"inputFormConfiguration.hint\">{{ inputFormConfiguration.hint }}</mat-hint>\n</mat-form-field>\n", styles: ["input::-webkit-outer-spin-button,input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}input[type=number]{-moz-appearance:textfield}\n"], components: [{ type: i2.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], directives: [{ type: i2.MatLabel, selector: "mat-label" }, { type: i7.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["id", "disabled", "required", "type", "value", "readonly", "placeholder", "errorStateMatcher", "aria-describedby"], exportAs: ["matInput"] }, { type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.MatSuffix, selector: "[matSuffix]" }, { type: i2.MatHint, selector: "mat-hint", inputs: ["align", "id"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'ag-input',
                    templateUrl: './ag-input.component.html',
                    styleUrls: ['./ag-input.component.scss'],
                }]
        }], propDecorators: { readonlyForDemo: [{
                type: Input
            }], inputFormConfiguration: [{
                type: Input
            }] } });

class AgDatePickerComponent {
    constructor(dateAdapter) {
        this.dateAdapter = dateAdapter;
    }
    ngOnInit() {
        this.setLocale();
    }
    setLocale() {
        this.dateAdapter.setLocale(this.datePickerConfiguration.locale);
    }
}
AgDatePickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerComponent, deps: [{ token: i6.DateAdapter }], target: i0.ɵɵFactoryTarget.Component });
AgDatePickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgDatePickerComponent, selector: "ag-date-picker", inputs: { datePickerConfiguration: "datePickerConfiguration" }, ngImport: i0, template: "<div [dir]=\"datePickerConfiguration.isRtl ? 'rtl' : 'ltr'\">\n    <mat-form-field [color]=\"datePickerConfiguration.themeColor\" [appearance]=\"datePickerConfiguration.appearance\">\n        <mat-label>{{ datePickerConfiguration.label }}</mat-label>\n        <input\n            matInput\n            [matDatepicker]=\"picker\"\n            [disabled]=\"datePickerConfiguration.disableMode === 'whole' || datePickerConfiguration.disableMode === 'input'\"\n        />\n        <mat-datepicker-toggle matSuffix [for]=\"picker\" [disabled]=\"datePickerConfiguration.disableMode === 'popup'\">\n            <mat-icon matDatepickerToggleIcon>{{ datePickerConfiguration.datePickerIcon }}</mat-icon>\n        </mat-datepicker-toggle>\n        <mat-datepicker #picker [color]=\"datePickerConfiguration.popupColor\" [disabled]=\"datePickerConfiguration.disableMode === 'whole'\"></mat-datepicker>\n        <mat-hint>{{ datePickerConfiguration.hint }}</mat-hint>\n    </mat-form-field>\n</div>\n", styles: [""], components: [{ type: i2.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i3$2.MatDatepickerToggle, selector: "mat-datepicker-toggle", inputs: ["tabIndex", "disabled", "for", "aria-label", "disableRipple"], exportAs: ["matDatepickerToggle"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i3$2.MatDatepicker, selector: "mat-datepicker", exportAs: ["matDatepicker"] }], directives: [{ type: i4$1.Dir, selector: "[dir]", inputs: ["dir"], outputs: ["dirChange"], exportAs: ["dir"] }, { type: i2.MatLabel, selector: "mat-label" }, { type: i7.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["id", "disabled", "required", "type", "value", "readonly", "placeholder", "errorStateMatcher", "aria-describedby"], exportAs: ["matInput"] }, { type: i3$2.MatDatepickerInput, selector: "input[matDatepicker]", inputs: ["matDatepicker", "min", "max", "matDatepickerFilter"], exportAs: ["matDatepickerInput"] }, { type: i2.MatSuffix, selector: "[matSuffix]" }, { type: i3$2.MatDatepickerToggleIcon, selector: "[matDatepickerToggleIcon]" }, { type: i2.MatHint, selector: "mat-hint", inputs: ["align", "id"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'ag-date-picker',
                    templateUrl: './ag-date-picker.component.html',
                    styleUrls: ['./ag-date-picker.component.scss'],
                }]
        }], ctorParameters: function () { return [{ type: i6.DateAdapter }]; }, propDecorators: { datePickerConfiguration: [{
                type: Input
            }] } });

class AgFormBuilderComponent {
    constructor(dialog, fb) {
        this.dialog = dialog;
        this.fb = fb;
        this.emittedFormInfo = new EventEmitter();
        this.sections = [];
        this.form = this.fb.group({
            name: [null, [Validators.required, Validators.pattern(/^[a-zA-Z]*$/)]],
        });
    }
    clearForm() {
        this.sections = [];
        this.form.reset();
    }
    addSection() {
        this.sections.push({ columnsCount: 0 });
    }
    removeSection(section) {
        const sectionIndex = this.sections.indexOf(section);
        this.sections.splice(sectionIndex, 1);
    }
    openSettingDialog(sectionIndex, sectionInfo) {
        this.dialog
            .open(AgSettingModalComponent, { data: { sectionIndex, sectionInfo }, height: '800px', width: '1600px' })
            .afterClosed()
            .subscribe((sectionInfo) => {
            sectionInfo && this.createSectionPreview(sectionInfo);
        });
    }
    submitForm() {
        this.emittedFormInfo.emit({ name: this.form.get('name').value, sections: this.sections });
    }
    isSubmitButtonDisable() {
        return this.form.valid && !!this.sections.length;
    }
    createSectionPreview(sectionInfo) {
        this.sections[sectionInfo.sectionIndex] = {
            columnInfo: sectionInfo.sectionColumns,
            columnsCount: sectionInfo.sectionColumns.length,
        };
    }
}
AgFormBuilderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgFormBuilderComponent, deps: [{ token: i1$1.MatDialog }, { token: i1.FormBuilder }], target: i0.ɵɵFactoryTarget.Component });
AgFormBuilderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.1", type: AgFormBuilderComponent, selector: "lib-ag-form-builder", outputs: { emittedFormInfo: "emittedFormInfo" }, ngImport: i0, template: "<mat-card class=\"ag-flex ag-flex-col ag-h-full ag-px-0 ag-pt-0 ag-bg-gray-100\">\n    <mat-card-header class=\"ag-flex ag-flex-col ag-text-center ag-m-0 ag-w-full ag-bg-blue-300 ag-mb-10\">\n        <mat-card-title class=\"ag-text-base ag-flex ag-justify-around ag-items-baseline ag-pt-5\">\n            <a href=\"https://github.com/hossein13m/angular-form-builder\" target=\"_blank\">\n                <h1 class=\"ag-flex ag-items-center\">\n                    <span class=\"ag-mx-2\"> AG FormBuilder </span>\n                    <mat-icon fontSet=\"material-icons-outlined\"> dashboard </mat-icon>\n                </h1>\n            </a>\n\n            <form (submit)=\"submitForm()\" id=\"form\" [formGroup]=\"form\">\n                <mat-form-field appearance=\"outline\" class=\"ag-mx-3 ag-flex ag-justify-center\">\n                    <mat-label>\n                        <span>Form Name</span>\n                    </mat-label>\n                    <input matInput type=\"text\" formControlName=\"name\" pattern=\"[a-zA-Z ]*\" />\n                    <button *ngIf=\"form.get('name')!.value\" matSuffix mat-icon-button (click)=\"form.get('name')?.setValue(null)\">\n                        <mat-icon fontSet=\"material-icons-outlined\">close</mat-icon>\n                    </button>\n                    <mat-hint *ngIf=\"!form.get('name')!.hasError('pattern')\" class=\"ag-flex\">\n                        <span>Can't be changed in future</span>\n                    </mat-hint>\n                    <mat-error *ngIf=\"form.get('name')!.hasError('pattern')\" class=\"ag-flex\">\n                        <span>Only English letters are accepted</span>\n                    </mat-error>\n                </mat-form-field>\n            </form>\n        </mat-card-title>\n\n        <mat-card-subtitle>\n            <hr class=\"ag-w-full ag-my-3\" />\n            <h3>Create your form by creating sections and then configure those section's column. In each Section you can set up to three components</h3>\n        </mat-card-subtitle>\n    </mat-card-header>\n\n    <mat-card-content class=\"ag-overflow-y-auto ag-h-5-6 ag-mt-10\">\n        <mat-grid-list cols=\"1\" rowHeight=\"150px\" gutterSize=\"30px\" class=\"ag-mx-5\">\n            <!-- section -->\n            <mat-grid-tile *ngFor=\"let section of sections; let index = index\" class=\"ag-w-full\">\n                <div class=\"ag-flex ag-flex-col ag-w-full ag-h-full\">\n                    <div class=\"ag-flex ag-justify-around ag-w-full ag-text-center ag-h-full ag-items-center\">\n                        <div *ngIf=\"sections[index].columnsCount === 0\" class=\"ag-flex ag-items-center\">\n                            <h1 class=\"ag-mb-0\">Click on setting button to add components into this section</h1>\n                        </div>\n                        <div\n                            class=\"ag-h-full ag-flex ag-justify-center ag-items-center ag-w-full component-group\"\n                            *ngFor=\"let column of sections[index].columnInfo\"\n                        >\n                            <ag-button *ngIf=\"column.componentInfo.componentType === 'button'\" [buttonConfiguration]=\"column.componentInfo\"> </ag-button>\n\n                            <ag-input\n                                *ngIf=\"column.componentInfo.componentType === 'input'\"\n                                [readonlyForDemo]=\"true\"\n                                [inputFormConfiguration]=\"column.componentInfo\"\n                            ></ag-input>\n\n                            <ag-date-picker\n                                *ngIf=\"column.componentInfo.componentType === 'datepicker'\"\n                                [datePickerConfiguration]=\"column.componentInfo\"\n                            ></ag-date-picker>\n                        </div>\n                    </div>\n\n                    <div class=\"ag-flex ag-flex-row ag-justify-around ag-mt-auto section-button\">\n                        <button\n                            mat-button\n                            class=\"ag-w-full p-1 ag-bg-blue-100 ag-hover-bg-blue-200\"\n                            matTooltip=\"Section Setting\"\n                            matTooltipPosition=\"below\"\n                            (click)=\"openSettingDialog(index, section)\"\n                        >\n                            <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-blue-600\">settings</mat-icon>\n                        </button>\n                        <button\n                            mat-button\n                            class=\"ag-w-full p-1 ag-bg-blue-100 ag-hover-bg-blue-200\"\n                            matTooltip=\"Remove Section\"\n                            matTooltipPosition=\"below\"\n                            (click)=\"removeSection(section)\"\n                        >\n                            <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-blue-600\">remove_circle</mat-icon>\n                        </button>\n                    </div>\n                </div>\n            </mat-grid-tile>\n\n            <!-- section empty state  -->\n            <button (click)=\"addSection()\">\n                <mat-grid-tile class=\"empty-state-section\" matTooltip=\"Add Section\" matTooltipPosition=\"below\">\n                    <mat-icon fontSet=\"material-icons-outlined\" class=\"add-section-button ag-flex ag-justify-center ag-items-center ag-text-blue-600\"\n                        >add_circle\n                    </mat-icon>\n                </mat-grid-tile>\n            </button>\n        </mat-grid-list>\n    </mat-card-content>\n\n    <mat-card-actions class=\"ag-flex ag-justify-around\">\n        <button mat-flat-button color=\"warn\" (click)=\"clearForm()\">\n            <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-2xl\" inline>restart_alt</mat-icon>\n            <span>Reset Form</span>\n        </button>\n\n        <button mat-flat-button color=\"primary\" class=\"ag-bg-light-blue-300\" form=\"form\" type=\"submit\" [disabled]=\"!isSubmitButtonDisable()\">\n            <mat-icon fontSet=\"material-icons-outlined\" class=\"ag-text-2xl\" inline>save</mat-icon>\n            <span>Save Form</span>\n        </button>\n    </mat-card-actions>\n</mat-card>\n", styles: [".ag-flex{display:flex!important}.ag-flex-col{flex-direction:column!important}.ag-justify-around{justify-content:space-around!important}.ag-justify-between{justify-content:space-between!important}.ag-justify-center{justify-content:center!important}.ag-justify-evenly{justify-content:space-evenly}.ag-items-baseline{align-items:baseline!important}.ag-items-center{align-items:center!important}.ag-items-end{align-items:end!important}.ag-w-full{width:100%!important}.ag-w-3-5{width:60%!important}.ag-w-5-6{width:83.333333%!important}.ag-text-base{font-size:1rem!important;line-height:1.5rem!important}.ag-text-center{text-align:center!important}.ag-h-full{height:100%!important}.ag-h-5-6{height:83.333333%!important}.ag-bg-gray-100{--tw-bg-opacity: 1;background-color:rgba(243,244,246,var(--tw-bg-opacity))}.ag-bg-blue-300{--tw-bg-opacity: 1;background-color:rgba(147,197,253,var(--tw-bg-opacity))}.ag-bg-blue-200{--tw-bg-opacity: 1;background-color:rgba(191,219,254,var(--tw-bg-opacity))}.ag-bg-blue-100{--tw-bg-opacity: 1;background-color:rgba(219,234,254,var(--tw-bg-opacity))}.ag-bg-light-blue-300{--tw-bg-opacity: 1;background-color:rgba(147,197,253,var(--tw-bg-opacity))}.ag-hover-bg-blue-200:hover{--tw-bg-opacity: 1;background-color:rgba(191,219,254,var(--tw-bg-opacity))}.ag-overflow-y-auto{overflow-y:auto!important}.ag-text-blue-600{--tw-text-opacity: 1 !important;color:rgba(37,99,235,var(--tw-text-opacity))!important}.ag-text-2xl{font-size:1.5rem!important;line-height:2rem!important}.ag-grid{display:grid!important}.ag-grid-cols-3{grid-template-columns:repeat(3,minmax(0,1fr))!important}.ag-max-w-full{max-width:100%!important}.ag-text-4xl{font-size:2.25rem!important;line-height:2.5rem!important}.ag-font-black{font-weight:900!important}.ag-text-lg{font-size:1.125rem!important;line-height:1.75rem!important}.ag-text-7xl{font-size:4.5rem!important;line-height:1!important}.ag-text-3xl{font-size:1.875rem!important;line-height:2.25rem!important}.ag-mx-0{margin-left:0!important;margin-right:0!important}.ag-mx-2{margin-left:.5rem!important;margin-right:.5rem!important}.ag-mx-3{margin-left:.75rem!important;margin-right:.75rem!important}.ag-mx-4{margin-left:1rem!important;margin-right:1rem!important}.ag-mx-5{margin-left:1.25rem!important;margin-right:1.25rem!important}.ag-mx-auto{margin-left:auto!important;margin-right:auto!important}.ag-mb-0{margin-bottom:0!important}.ag-mb-3-5{margin-bottom:.875rem!important}.ag-mb-10{margin-bottom:-2.5rem!important}.ag-mt-auto{margin-top:auto!important}.ag-ml-4{margin-left:1rem!important}.ag-my-2{margin-top:.5rem!important;margin-bottom:.5rem!important}.ag-my-3{margin-top:.75rem!important;margin-bottom:.75rem!important}.ag-mt-10{margin-top:2.5rem!important}.ag-my-auto{margin-top:auto!important;margin-bottom:auto!important}.ag-px-3-5{padding-left:.875rem!important;padding-right:.875rem!important}.ag-px-0{padding-left:0!important;padding-right:0!important}.ag-py-14{padding-top:3.5rem!important;padding-bottom:3.5rem!important}.ag-pt-0{padding-top:0!important}.ag-pt-5{padding-top:1.25rem!important}.ag-m-0{margin:0!important}.ag-p-0{padding:0!important}mat-card{display:flex}mat-card mat-card-content mat-grid-list{min-width:1400px;padding:20px}mat-card mat-card-content mat-grid-list .empty-state-section{border:3px dashed #3f51b5;opacity:.8;background:#e1edfc repeating-linear-gradient(45deg,#e7f4ff,#e7f4ff 5px,#e1edfc 5px,#e1edfc 25px);cursor:pointer}mat-card mat-card-content mat-grid-list .component-group:nth-of-type(2n){border-left:4px solid #b9b9b9}mat-card mat-card-content mat-grid-list .component-group:nth-of-type(2n + 3){border-left:4px solid #b9b9b9}mat-card mat-card-content mat-grid-list mat-grid-tile{border-radius:10px;background:#ecf1f5}mat-card mat-card-content mat-grid-list mat-grid-tile .add-section-button{font-size:70px}\n"], components: [{ type: i3$1.MatCard, selector: "mat-card", exportAs: ["matCard"] }, { type: i3$1.MatCardHeader, selector: "mat-card-header" }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i2.MatFormField, selector: "mat-form-field", inputs: ["color", "floatLabel", "appearance", "hideRequiredMarker", "hintLabel"], exportAs: ["matFormField"] }, { type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i7$2.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i7$2.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: AgButtonComponent, selector: "ag-button", inputs: ["disableButton", "buttonConfiguration"] }, { type: AgInputComponent, selector: "ag-input", inputs: ["readonlyForDemo", "inputFormConfiguration"] }, { type: AgDatePickerComponent, selector: "ag-date-picker", inputs: ["datePickerConfiguration"] }], directives: [{ type: i3$1.MatCardTitle, selector: "mat-card-title, [mat-card-title], [matCardTitle]" }, { type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i2.MatLabel, selector: "mat-label" }, { type: i7.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["id", "disabled", "required", "type", "value", "readonly", "placeholder", "errorStateMatcher", "aria-describedby"], exportAs: ["matInput"] }, { type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i1.FormControlName, selector: "[formControlName]", inputs: ["disabled", "formControlName", "ngModel"], outputs: ["ngModelChange"] }, { type: i1.PatternValidator, selector: "[pattern][formControlName],[pattern][formControl],[pattern][ngModel]", inputs: ["pattern"] }, { type: i8.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i2.MatSuffix, selector: "[matSuffix]" }, { type: i2.MatHint, selector: "mat-hint", inputs: ["align", "id"] }, { type: i2.MatError, selector: "mat-error", inputs: ["id"] }, { type: i3$1.MatCardSubtitle, selector: "mat-card-subtitle, [mat-card-subtitle], [matCardSubtitle]" }, { type: i3$1.MatCardContent, selector: "mat-card-content, [mat-card-content], [matCardContent]" }, { type: i8.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i12.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { type: i3$1.MatCardActions, selector: "mat-card-actions", inputs: ["align"], exportAs: ["matCardActions"] }], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgFormBuilderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'lib-ag-form-builder',
                    templateUrl: './ag-form-builder.component.html',
                    styleUrls: ['./ag-form-builder.component.scss'],
                    encapsulation: ViewEncapsulation.None,
                }]
        }], ctorParameters: function () { return [{ type: i1$1.MatDialog }, { type: i1.FormBuilder }]; }, propDecorators: { emittedFormInfo: [{
                type: Output
            }] } });

class AgButtonModule {
}
AgButtonModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgButtonModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonModule, declarations: [AgButtonComponent], imports: [CommonModule, MatButtonModule, MatTooltipModule, MatIconModule, RouterModule], exports: [AgButtonComponent] });
AgButtonModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonModule, imports: [[CommonModule, MatButtonModule, MatTooltipModule, MatIconModule, RouterModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AgButtonComponent],
                    imports: [CommonModule, MatButtonModule, MatTooltipModule, MatIconModule, RouterModule],
                    exports: [AgButtonComponent],
                }]
        }] });

class AgButtonConfigurationModule {
}
AgButtonConfigurationModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonConfigurationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgButtonConfigurationModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonConfigurationModule, declarations: [AgButtonConfigurationComponent], imports: [CommonModule,
        MatFormFieldModule,
        MatSelectModule,
        ReactiveFormsModule,
        MatInputModule,
        MatIconModule,
        MatButtonModule,
        MatSlideToggleModule,
        MatRadioModule], exports: [AgButtonConfigurationComponent] });
AgButtonConfigurationModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonConfigurationModule, imports: [[
            CommonModule,
            MatFormFieldModule,
            MatSelectModule,
            ReactiveFormsModule,
            MatInputModule,
            MatIconModule,
            MatButtonModule,
            MatSlideToggleModule,
            MatRadioModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgButtonConfigurationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AgButtonConfigurationComponent],
                    imports: [
                        CommonModule,
                        MatFormFieldModule,
                        MatSelectModule,
                        ReactiveFormsModule,
                        MatInputModule,
                        MatIconModule,
                        MatButtonModule,
                        MatSlideToggleModule,
                        MatRadioModule,
                    ],
                    exports: [AgButtonConfigurationComponent],
                }]
        }] });

class AgDatePickerConfigurationModule {
}
AgDatePickerConfigurationModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerConfigurationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgDatePickerConfigurationModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerConfigurationModule, declarations: [AgDatePickerConfigurationComponent], imports: [CommonModule,
        MatSelectModule,
        MatIconModule,
        ReactiveFormsModule,
        MatInputModule,
        MatButtonModule], exports: [AgDatePickerConfigurationComponent] });
AgDatePickerConfigurationModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerConfigurationModule, imports: [[
            CommonModule,
            MatSelectModule,
            MatIconModule,
            ReactiveFormsModule,
            MatInputModule,
            MatButtonModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerConfigurationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        AgDatePickerConfigurationComponent
                    ],
                    exports: [
                        AgDatePickerConfigurationComponent
                    ],
                    imports: [
                        CommonModule,
                        MatSelectModule,
                        MatIconModule,
                        ReactiveFormsModule,
                        MatInputModule,
                        MatButtonModule
                    ]
                }]
        }] });

class AgInputConfigurationModule {
}
AgInputConfigurationModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputConfigurationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgInputConfigurationModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputConfigurationModule, declarations: [AgInputConfigurationComponent], imports: [CommonModule, ReactiveFormsModule, MatFormFieldModule, MatIconModule, MatInputModule, MatSelectModule, MatButtonModule, MatSlideToggleModule], exports: [AgInputConfigurationComponent] });
AgInputConfigurationModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputConfigurationModule, imports: [[CommonModule, ReactiveFormsModule, MatFormFieldModule, MatIconModule, MatInputModule, MatSelectModule, MatButtonModule, MatSlideToggleModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputConfigurationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AgInputConfigurationComponent],
                    imports: [CommonModule, ReactiveFormsModule, MatFormFieldModule, MatIconModule, MatInputModule, MatSelectModule, MatButtonModule, MatSlideToggleModule],
                    exports: [AgInputConfigurationComponent],
                }]
        }] });

class AgSettingModalModule {
}
AgSettingModalModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgSettingModalModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgSettingModalModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgSettingModalModule, declarations: [AgSettingModalComponent], imports: [CommonModule,
        MatCardModule,
        MatFormFieldModule,
        MatOptionModule,
        MatSelectModule,
        MatButtonModule,
        AgInputConfigurationModule,
        AgButtonConfigurationModule,
        MatIconModule,
        MatDividerModule,
        MatTooltipModule,
        AgDatePickerConfigurationModule], exports: [AgSettingModalComponent] });
AgSettingModalModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgSettingModalModule, imports: [[
            CommonModule,
            MatCardModule,
            MatFormFieldModule,
            MatOptionModule,
            MatSelectModule,
            MatButtonModule,
            AgInputConfigurationModule,
            AgButtonConfigurationModule,
            MatIconModule,
            MatDividerModule,
            MatTooltipModule,
            AgDatePickerConfigurationModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgSettingModalModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AgSettingModalComponent],
                    imports: [
                        CommonModule,
                        MatCardModule,
                        MatFormFieldModule,
                        MatOptionModule,
                        MatSelectModule,
                        MatButtonModule,
                        AgInputConfigurationModule,
                        AgButtonConfigurationModule,
                        MatIconModule,
                        MatDividerModule,
                        MatTooltipModule,
                        AgDatePickerConfigurationModule,
                    ],
                    entryComponents: [AgSettingModalComponent],
                    exports: [AgSettingModalComponent],
                }]
        }] });

class AgInputModule {
}
AgInputModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgInputModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputModule, declarations: [AgInputComponent], imports: [CommonModule, MatInputModule, ReactiveFormsModule, MatIconModule, MatButtonModule], exports: [AgInputComponent] });
AgInputModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputModule, imports: [[CommonModule, MatInputModule, ReactiveFormsModule, MatIconModule, MatButtonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgInputModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AgInputComponent],
                    imports: [CommonModule, MatInputModule, ReactiveFormsModule, MatIconModule, MatButtonModule],
                    exports: [AgInputComponent],
                }]
        }] });

class AgDatePickerModule {
}
AgDatePickerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgDatePickerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerModule, declarations: [AgDatePickerComponent], imports: [CommonModule, MatFormFieldModule, MatInputModule, MatDatepickerModule, MatNativeDateModule, MatIconModule], exports: [AgDatePickerComponent] });
AgDatePickerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerModule, imports: [[CommonModule, MatFormFieldModule, MatInputModule, MatDatepickerModule, MatNativeDateModule, MatIconModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgDatePickerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AgDatePickerComponent],
                    exports: [AgDatePickerComponent],
                    imports: [CommonModule, MatFormFieldModule, MatInputModule, MatDatepickerModule, MatNativeDateModule, MatIconModule]
                }]
        }] });

class AgFormBuilderModule {
}
AgFormBuilderModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgFormBuilderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AgFormBuilderModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgFormBuilderModule, declarations: [AgFormBuilderComponent], imports: [CommonModule,
        MatCardModule,
        MatButtonModule,
        MatGridListModule,
        AgButtonModule,
        MatIconModule,
        MatTooltipModule,
        MatDialogModule,
        AgSettingModalModule,
        MatFormFieldModule,
        MatInputModule,
        ReactiveFormsModule,
        AgInputModule,
        AgDatePickerModule], exports: [AgFormBuilderComponent] });
AgFormBuilderModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgFormBuilderModule, imports: [[
            CommonModule,
            MatCardModule,
            MatButtonModule,
            MatGridListModule,
            AgButtonModule,
            MatIconModule,
            MatTooltipModule,
            MatDialogModule,
            AgSettingModalModule,
            MatFormFieldModule,
            MatInputModule,
            ReactiveFormsModule,
            AgInputModule,
            AgDatePickerModule,
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.1", ngImport: i0, type: AgFormBuilderModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [AgFormBuilderComponent],
                    imports: [
                        CommonModule,
                        MatCardModule,
                        MatButtonModule,
                        MatGridListModule,
                        AgButtonModule,
                        MatIconModule,
                        MatTooltipModule,
                        MatDialogModule,
                        AgSettingModalModule,
                        MatFormFieldModule,
                        MatInputModule,
                        ReactiveFormsModule,
                        AgInputModule,
                        AgDatePickerModule,
                    ],
                    exports: [AgFormBuilderComponent],
                }]
        }] });

/*
 * Public API Surface of ag-form-builder
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AgFormBuilderComponent, AgFormBuilderModule };
//# sourceMappingURL=ag-form-builder.js.map
